@@ -8,12 +8,12 @@ package Printer::ESCPOS;
 #
 # This file is part of Printer-ESCPOS
 #
-# This software is copyright (c) 2016 by Shantanu Bhadoria.
+# This software is copyright (c) 2017 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '1.005'; # VERSION
+our $VERSION = '1.006'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -161,8 +161,8 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 <p>
 <img src="https://img.shields.io/badge/perl-5.10+-brightgreen.svg" alt="Requires Perl 5.10+" />
 <a href="https://travis-ci.org/shantanubhadoria/perl-Printer-ESCPOS"><img src="https://api.travis-ci.org/shantanubhadoria/perl-Printer-ESCPOS.svg?branch=build/master" alt="Travis status" /></a>
-<a href="http://matrix.cpantesters.org/?dist=Printer-ESCPOS%201.005"><img src="https://badgedepot.code301.com/badge/cpantesters/Printer-ESCPOS/1.005" alt="CPAN Testers result" /></a>
-<a href="http://cpants.cpanauthors.org/dist/Printer-ESCPOS-1.005"><img src="https://badgedepot.code301.com/badge/kwalitee/Printer-ESCPOS/1.005" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Printer-ESCPOS%201.006"><img src="http://badgedepot.code301.com/badge/cpantesters/Printer-ESCPOS/1.006" alt="CPAN Testers result" /></a>
+<a href="http://cpants.cpanauthors.org/release/_/Printer-ESCPOS-1.006"><img src="http://badgedepot.code301.com/badge/kwalitee/_/Printer-ESCPOS/1.006" alt="Distribution kwalitee" /></a>
 <a href="https://gratipay.com/shantanubhadoria"><img src="https://img.shields.io/gratipay/shantanubhadoria.svg" alt="Gratipay" /></a>
 </p>
 
@@ -170,7 +170,7 @@ Printer::ESCPOS - Interface for all thermal, dot-matrix and other receipt printe
 
 =head1 VERSION
 
-version 1.005
+version 1.006
 
 =head1 SYNOPSIS
 
@@ -583,15 +583,25 @@ L<https://github.com/shantanubhadoria/perl-printer-escpos>
 
 Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
-=head1 CONTRIBUTOR
+=head1 CONTRIBUTORS
 
-=for stopwords Shantanu Bhadoria
+=for stopwords Dominic Sonntag Shantanu Bhadoria
+
+=over 4
+
+=item *
+
+Dominic Sonntag <dominic@s5g.de>
+
+=item *
 
 Shantanu Bhadoria <shantanu att cpan dott org>
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Shantanu Bhadoria.
+This software is copyright (c) 2017 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
