@@ -8,12 +8,12 @@ package Printer::ESCPOS::Connections::USB;
 #
 # This file is part of Printer-ESCPOS
 #
-# This software is copyright (c) 2016 by Shantanu Bhadoria.
+# This software is copyright (c) 2017 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '1.005'; # VERSION
+our $VERSION = '1.006'; # VERSION
 
 # Dependencies
 
@@ -22,6 +22,7 @@ use Moo;
 with 'Printer::ESCPOS::Roles::Connection';
 
 use Device::USB;
+use Time::HiRes qw(usleep);
 
 
 has vendorId => (
@@ -96,8 +97,14 @@ sub print {
         $self->_buffer('');
     }
 
-    $self->_connection->bulk_write( $self->endPoint, $buffer, $self->timeout );
-
+    my $n = 2**14;    # Size of each chunk in bytes
+    @chunks = unpack "a$n" x ( ( length($buffer) / $n ) - 1 ) . "a*", $buffer;
+    for my $chunk (@chunks) {
+        $self->_connection->bulk_write( $self->endPoint, $chunk,
+            $self->timeout );
+        usleep(10000)
+          ; # USB Port is sometimes annoying, it doesn't always tell you when it is ready to get the next chunk
+    }
 }
 
 no Moo;
@@ -115,7 +122,7 @@ Printer::ESCPOS::Connections::USB - USB Connection Interface for L<Printer::ESCP
 
 =head1 VERSION
 
-version 1.005
+version 1.006
 
 =head1 SYNOPSIS
 
@@ -196,7 +203,7 @@ Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Shantanu Bhadoria.
+This software is copyright (c) 2017 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
