@@ -8,12 +8,12 @@ package Printer::ESCPOS::Profiles::Generic;
 #
 # This file is part of Printer-ESCPOS
 #
-# This software is copyright (c) 2016 by Shantanu Bhadoria.
+# This software is copyright (c) 2017 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '1.005'; # VERSION
+our $VERSION = '1.006'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -126,7 +126,7 @@ sub image {
 'Width is greater than 512 pixels and could be truncated at print time';
     }
     if ( $img->height > 255 ) {
-        confess 'Height is greated than 255 pixels';
+        confess 'Height is greater than 255 pixels';
     }
 
     my @padding = $self->_pad_image_size( $img->width );
@@ -774,7 +774,7 @@ Printer::ESCPOS::Profiles::Generic - Generic Profile for Printers for L<Printer:
 
 =head1 VERSION
 
-version 1.005
+version 1.006
 
 =head1 METHODS
 
@@ -918,16 +918,16 @@ Sets horizontal tab positions for tab stops. Upto 32 tab positions can be set in
 I<tabPositions>: a list of positions for tab().
 
     $device->printer->tabPositions( 5, 9, 13 );
-    printer.tabPositions(5, 9, 13);
 
-    for my $plu (@plus):
-        $device->printer->text($plu{quantity});
+    for my $plu (@plus) {
+        $device->printer->text($plu->{quantity});
         $device->printer->tab();
-        $device->printer->text(' x ' . plu{name});
+        $device->printer->text(' x ' . $plu->{name});
         $device->printer->tab();
-        $device->printer->text('$' . plu{price});
+        $device->printer->text('$' . $plu->{price});
+    }
 
-    This would print a well aligned receipt like so::
+This would print a well aligned receipt like so:
 
     10 x Guiness Beer              $24.00
     2  x Pizza                     $500.50
@@ -1355,7 +1355,7 @@ Shantanu Bhadoria <shantanu@cpan.org> L<https://www.shantanubhadoria.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Shantanu Bhadoria.
+This software is copyright (c) 2017 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
